<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="kn_IN">
<context>
    <name>AddonsPage</name>
    <message>
        <location filename="../qml/AddonsPage.qml" line="20"/>
        <source>Add-ons</source>
        <translation>ಅಡ್ಡಾನ್ಸ್</translation>
    </message>
</context>
<context>
    <name>AdvancedSettingsModule</name>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="15"/>
        <source>Advanced Settings</source>
        <translation>ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="41"/>
        <source>&quot;Advanced Settings&quot; is only valid for the input method that uses the system settings, if the input method has its own settings, its own settings shall prevail.</source>
        <translation>ಅಡ್ಡಾನ್ಸ್ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಸಂಪೂರ್ಣ ಸೆಟ್ಟಿಂಗ್ಸ್ ಬಳಸುವ ಇನ್ಪುಟ್ ಮೆಥಡ್ಗೆ ಮಾತ್ರ ಅನ್ವಯಿಸುವುದು, ಇನ್ಪುಟ್ ಮೆಥಡ್ ತನ್ನದೇ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಹೊಂದಿದ್ದರೆ, ಅದು ತನ್ನದೇ ಸೆಟ್ಟಿಂಗ್ಸ್ ಅನ್ನು ಅನ್ವಯಿಸುವುದು.</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="54"/>
        <source>Global Config</source>
        <translation>ಗ್ಲೋಬಲ್ ಕಂಫಿಗ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="70"/>
        <source>Add-ons</source>
        <translation>ಅಡ್ಡಾನ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/AdvancedSettingsModule.qml" line="81"/>
        <source>Keyboard layout</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DetailConfigItem</name>
    <message>
        <location filename="../qml/DetailConfigItem.qml" line="151"/>
        <source>Please enter a new shortcut</source>
        <translation>ನೂತನ ಶರ್ಕ್ಯಟ್ ನಮ್ಮನ್ನು ಪ್ರವೇಶಿಸಿ</translation>
    </message>
</context>
<context>
    <name>IMList</name>
    <message>
        <location filename="../qml/IMList.qml" line="152"/>
        <source>Move Up</source>
        <translation>ಮೇಲೆ ಸರಿಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="160"/>
        <source>Move Down</source>
        <translation>ಕೆಳಗೆ ಸರಿಯಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="168"/>
        <source>Settings</source>
        <translation>ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/IMList.qml" line="176"/>
        <source>Remove</source>
        <translation>ಅপ್ರಾಪ್ತ</translation>
    </message>
</context>
<context>
    <name>InputMethodsChooser</name>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="35"/>
        <source>Add input method</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಸೇರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="41"/>
        <source>Search</source>
        <translation>ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="109"/>
        <source>Find more in App Store</source>
        <translation>ಅಪ್ಪ್ ಸ್ಟೋರ್ನಲ್ಲಿ ಹೆಚ್ಚಿನವನ್ನು ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="129"/>
        <source>Cancel</source>
        <translation>ರದ್ದು</translation>
    </message>
    <message>
        <location filename="../qml/InputMethodsChooser.qml" line="136"/>
        <source>Add</source>
        <translation>ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>KeyboardLayout</name>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation>ಕೀಬೋರ್ಡ್ ಲೇಆಟ್</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>done</source>
        <translation>ಸಮಾಪ್ತ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="34"/>
        <source>edit</source>
        <translation>ಸಂಪಾದಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation>ಅನುಗುಣವಾದ ಇನ್ಪುಟ್ ಮೆಥಡ್ವನ್ನು &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ&lt;/a&gt; ಅನ್ನು ಸೇರಿಸಿ ಕೀಬೋರ್ಡ್ ಲೇಆಟ್ ಅನ್ನು ಸಕ್ರಿಯಗೊಳಿಸುವುದನ್ನು ನೀಡಿ.</translation>
    </message>
    <message>
        <location filename="../qml/KeyboardLayout.qml" line="142"/>
        <source>Add new keyboard layout...</source>
        <translation>ಹೊಸ ಕೀಬೋರ್ಡ್ ಲೇಆಟ್ ಸೇರಿಸಿ...</translation>
    </message>
</context>
<context>
    <name>KeyboardLayoutModule</name>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="16"/>
        <source>Keyboard layout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>done</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="34"/>
        <source>edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="57"/>
        <source>Add the corresponding input method in &lt;a style=&apos;text-decoration: none;&apos; href=&apos;Manage Input Methods&apos;&gt;Input Method Management&lt;/a&gt; to ensure the keyboard layout works when added or switched.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../qml/KeyboardLayoutModule.qml" line="140"/>
        <source>Add new keyboard layout...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>LayoutsChooser</name>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="30"/>
        <source>Add new keyboard layout</source>
        <translation>ಹೊಸ ಕೀಬೋರ್ಡ್ ಲೇಆಟ್ ಸೇರಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="38"/>
        <source>Search</source>
        <translation>ಹುಡುಕಿ</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="67"/>
        <source>Current language keyboard layouts</source>
        <translation>ಪ್ರಸ್ತುತ ಭಾಷೆಯ ಕೀಬೋರ್ಡ್ ಲೇಆಟ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="90"/>
        <source>Cancel</source>
            <translation>ರದ್ದು</translation>
    </message>
    <message>
        <location filename="../qml/LayoutsChooser.qml" line="97"/>
        <source>Add</source>
        <translation>ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ManageInputMethodsModule</name>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="15"/>
        <source>Input method management</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ</translation>
    </message>
    <message>
        <location filename="../qml/ManageInputMethodsModule.qml" line="33"/>
        <source>Add input method</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಸೇರಿಸಿ</translation>
    </message>
</context>
<context>
    <name>ShortcutsModule</name>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="12"/>
        <location filename="../qml/ShortcutsModule.qml" line="14"/>
        <location filename="../qml/ShortcutsModule.qml" line="151"/>
        <location filename="../qml/ShortcutsModule.qml" line="152"/>
        <source>None</source>
        <translation>ಯಾವುದೂ ಇಲ್ಲ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="119"/>
        <source>Shortcuts</source>
        <translation>ಶರ್ಕ್ಯಟ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="134"/>
        <source>Restore Defaults</source>
        <translation>ಪ್ರಮಾಣಿತ ಮೌಲ್ಯಗಳನ್ನು ಪುನರ್ಸ್ಥಾಪಿಸಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="200"/>
        <source>Scroll between input methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಗಳ ನಡುವೆ ಸ್ಕ್ರೋಲ್ ಮಾಡಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="230"/>
        <source>Turn on or off input methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಗಳನ್ನು ಸಕ್ರಿಯಗೊಳಿಸಿ ಅಥವಾ ಬಂದು ಕೊಳ್ಳಿ</translation>
    </message>
    <message>
        <location filename="../qml/ShortcutsModule.qml" line="273"/>
        <source>It turns on or off the currently used input method.If no input method is being used or the first input method is not the keyboard, it switches between the first input method and the currently used keyboard/input method.</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಅನ್ನು ಸಕ್ರಿಯಗೊಳಿಸುವುದು ಅಥವಾ ಬಂದು ಕೊಳ್ಳುವುದು. ಇನ್ಪುಟ್ ಮೆಥಡ್ ಬಳಸಲಾಗಿಲ್ಲ ಅಥವಾ ಮೊದಲ ಇನ್ಪುಟ್ ಮೆಥಡ್ ಕೀಬೋರ್ಡ್ ಅಲ್ಲದಿದ್ದರೆ, ಅದು ಮೊದಲ ಇನ್ಪುಟ್ ಮೆಥಡ್ ಮತ್ತು ಇನ್ಪುಟ್ ಮೆಥಡ್ ಅನ್ನು ಬದಲಾಯಿಸುತ್ತದೆ.</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::dialectNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="62"/>
        <source>Traditional Chinese (Chinese Hong Kong)</source>
        <translation>ಕ್ಯಾಚಿನ್ ಕ್ಯಾಚಿನ್ (ಕ್ಯಾಚಿನ್ ಹಾಂಗ್ ಕಾಂಗ್)</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="65"/>
        <source>Traditional Chinese (Chinese Taiwan)</source>
        <translation>ಕ್ಯಾಚಿನ್ ಕ್ಯಾಚಿನ್ (ಕ್ಯಾಚಿನ್ ತೈವಾನ್)</translation>
    </message>
</context>
<context>
    <name>dcc::Locale::regionNames</name>
    <message>
        <location filename="../keyboard-layout/operation/dcclocale.cpp" line="86"/>
        <source>Taiwan China</source>
        <translation>ತೈವಾನ್ ಕ್ಯಾಚಿನ್</translation>
    </message>
</context>
<context>
    <name>dccV25::KeyboardController</name>
    <message>
        <location filename="../keyboard-layout/operation/keyboardcontroller.cpp" line="55"/>
        <source>This shortcut conflicts with [%1]</source>
            <translation>ಈ ಶರ್ಕ್ಯಟ್ ಕಾನ್ಫ್ಲಿಕ್ಟ್ ಆಗಿದೆ [%1]</translation>
    </message>
</context>
<context>
    <name>dccV25::ShortcutModel</name>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="248"/>
        <source>System</source>
        <translation>ಸಿಸ್ಟಮ್</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="253"/>
        <source>Window</source>
        <translation>ವಿಂಡೋ</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="258"/>
        <source>Workspace</source>
        <translation>ವರ್ಕ್ಸ್ಪೇಸ್</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="263"/>
        <source>AssistiveTools</source>
        <translation>ಸಹಾಯಕ ಕರಗಳು</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="268"/>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="339"/>
        <source>Custom</source>
        <translation>ಕಸ್ಟಮ್</translation>
    </message>
    <message>
        <location filename="../keyboard-layout/operation/shortcutmodel.cpp" line="394"/>
        <source>None</source>
        <translation>ಯಾವುದೂ ಇಲ್ಲ</translation>
    </message>
</context>
<context>
    <name>fcitx5configtool</name>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="8"/>
        <source>Input Methods</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ಸ್</translation>
    </message>
    <message>
        <location filename="../qml/fcitx5configtool.qml" line="9"/>
        <source>Input method management, input method shortcuts, advanced settings</source>
        <translation>ಇನ್ಪುಟ್ ಮೆಥಡ್ ಪರಿಪಾಲನೆ, ಇನ್ಪುಟ್ ಮೆಥಡ್ ಶರ್ಕ್ಯಟ್ಸ್, ಅಧುನಿಕ ಸೆಟ್ಟಿಂಗ್ಸ್</translation>
    </message>
</context>
</TS>